import 'package:flutter/material.dart';
import 'package:medapay/src/components/payment_option.dart';

const Map<String, Map<String, String>> _availablePaymentOptions = {
  'amole': {
    'title': 'Amole',
    'subtitle': 'Powered by Dashen Bank',
    'icon': 'packages/medapay/assets/images/amole.png'
  },
  'cbebirr': {
    'title': 'CBE Birr',
    'subtitle': 'Commercial Bank of Ethiopia',
    'icon': 'packages/medapay/assets/images/cbebirr.png'
  },
  'ebirr': {
    'title': 'E-Birr',
    'subtitle': 'Fast & Secure Payments',
    'icon': 'packages/medapay/assets/images/ebirr.png'
  },
  'boa': {
    'title': 'Abyssinia Bank',
    'subtitle': 'Bank of Abyssinia',
    'icon': 'packages/medapay/assets/images/boa.png'
  },
  'mbirr': {
    'title': 'mBirr',
    'subtitle': 'Mobile Money',
    'icon': 'packages/medapay/assets/images/mbirr.png'
  },
  'hellocash': {
    'title': 'HelloCash',
    'subtitle': 'Mobile Financial Inclusion',
    'icon': 'packages/medapay/assets/images/hellocash.png'
  },
};

class PaymentOptions extends StatelessWidget {
  final Function onSelected;
  final String value;
  final List<String> paymentMethods;

  const PaymentOptions(
      {Key key, this.onSelected, this.value, this.paymentMethods})
      : super(key: key);

  List<Widget> _buildOptions() {
    List<Widget> _paymentOptions = [];
    // toSet().toList() flushes out redundant values
    paymentMethods.toSet().toList().forEach((paymentMethod) {
      if (_availablePaymentOptions.containsKey(paymentMethod)) {
        _paymentOptions.add(SizedBox(
          height: 10,
        ));
        _paymentOptions.add(PaymentOption(
          isActive: value == paymentMethod,
          onPressed: () {
            onSelected(paymentMethod);
          },
          title: _availablePaymentOptions[paymentMethod]['title'],
          subtitle: _availablePaymentOptions[paymentMethod]['subtitle'],
          imagePath: _availablePaymentOptions[paymentMethod]['icon'],
        ));
      }
    });

    _paymentOptions.add(SizedBox(
      height: 10,
    ));

    return _paymentOptions;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 20, vertical: 10),
      child: Column(
        children: _buildOptions(),
      ),
    );
  }
}
